@@ -1,6 +1,6 @@
 package PDL::NDBin;
 {
-  $PDL::NDBin::VERSION = '0.013';
+  $PDL::NDBin::VERSION = '0.014';
 }
 # ABSTRACT: Multidimensional binning & histogramming
 
@@ -196,6 +196,11 @@ sub autoscale_axis
 	}
 	# first get & sanify the arguments
 	croak( 'need coordinates' ) unless defined $axis->{pdl};
+	# return if axis is empty
+	if( $axis->{pdl}->isempty ) {
+		$axis->{n} = 0;
+		return;
+	}
 	$axis->{min} = $axis->{pdl}->min unless defined $axis->{min};
 
 
@@ -309,6 +314,7 @@ sub process
 		$log->debug( 'input (' . $axis->{pdl}->info . ') = ' . $axis->{pdl} ) if $log->is_debug;
 		$log->debug( "bin with parameters step=$axis->{step}, min=$axis->{min}, n=$axis->{n}" )
 			if $log->is_debug;
+		croak( 'I cannot bin unless n > 0' ) unless $axis->{n} > 0;
 		unshift @n, $axis->{n};			# remember that we are working backwards!
 		$idx = $axis->{pdl}->_flatten_into( $idx, $axis->{step}, $axis->{min}, $axis->{n} );
 	}
@@ -523,7 +529,7 @@ PDL::NDBin - Multidimensional binning & histogramming
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
